const express = require('express');
const logger = require('morgan');
const cookieParser = require('cookie-parser');
const bodyParser = require('body-parser');
const session = require('express-session');
const mongoose = require('mongoose');
const MongoStore = require('connect-mongo')(session);

require('dotenv').config();

const square = require('./routes/square.route');
const merchant = require('./routes/merchant.route');
const campaign = require('./routes/campaign.route');
const subscriber = require('./routes/subscriber.route');
const stripe = require('./routes/stripe.route');
const message = require('./routes/message.route');
const order = require('./routes/order.route');
const wallet = require('./routes/wallet.route');

const app = express();

app.use(function (req, res, next) {
    res.header("Access-Control-Allow-Origin", `*`);
    res.header("Access-Control-Allow-Headers", "Access-Control-Allow-Headers, Origin, Accept, X-Requested-With, Content-Type, Access-Control-Request-Method, Access-Control-Request-Headers, X-JWT-Token");
    res.header("Access-Control-Allow-Methods", "DELETE, PUT, PATCH, OPTIONS");
    next();
});

app.use(bodyParser.json({
    type: 'application/json',
    limit: '50mb',
    verify: function (req, res, buf) {
        if (req.url.startsWith('/webhook')) {
            req.rawbody = buf;
        }
    }
}));

app.use(logger('dev'));

app.use(bodyParser.urlencoded({ extended: false }));
app.use(bodyParser.json());

app.use(cookieParser());
app.set('trust proxy', 1);

app.use(session({
    name: 'SMSDashboardApp',
    secret: process.env.SESSION_SECRET || 'coocoocachoo',
    cookie: { secure: true, maxAge: (24 * 60 * 60 * 1000) },
    saveUninitialized: true,
    resave: false,
    store: new MongoStore({ mongooseConnection: mongoose.connection }),
}));

app.disable('etag');

// Routes
app.use('/square/', square);
app.use('/merchant/', merchant);
app.use('/campaign/', campaign);
app.use('/subscriber/', subscriber);
app.use('/stripe/', stripe);
app.use('/message/', message);
app.use('/order/', order);
app.use('/wallet/', wallet);

// catch 404 and forward to error handler
app.use((req, res, next) => {
    const err = new Error('Not Found');
    err.status = 404;
    next(err);
});
// error handler
app.use((err, req, res) => {
    // set locals, only providing error in development
    res.locals.message = err.message;
    res.locals.error = req.app.get('env') === 'development' ? err : {};

    // render the error page
    res.status(err.status || 500);
    res.render('error');
});



module.exports = app;