const mongoose = require("mongoose");
const { decodeToken } = require("../helpers/jwt.helper");
const Wallet = mongoose.model("Wallet");
const Merchant = mongoose.model('Merchant');
const Stripe = require('stripe');
const stripe = Stripe(process.env.STRIPE_SECRET_KEY);
const getTransactionHistory = async (req, res) => {
    try {
        const token = req.get("X-JWT-Token");
        const decodedToken = decodeToken(token);
        if (!decodedToken) {
            res.status(201).send({ message: 'token not provided !' });
            return
        }

        const merchant = await Merchant.findById(decodedToken.data.merchantId);
        if (!merchant) {
            res.status(201).send({ message: 'please provide merchant id' });
            return
        }
        const wallet = await Wallet.find({
            merchant: merchant._id,
        }).sort({ createdAt: -1 });
        res.status(200).send(wallet);

    } catch (error) {
        res.status(400).send({
            message: error.message
        })
    }
}

const rechargeWallet = async (req, res) => {
    try {
        var charged ;
        const { cardToken, amount, cardId } = req.body
        console.log("req.body => ", req.body);
        const token = req.get("X-JWT-Token");
        const decodedToken = decodeToken(token);
        if (!decodedToken) {
            res.status(201).send({ message: 'token not provided !' });
            return
        }

        const merchant = await Merchant.findById(decodedToken.data.merchantId);
        if (!merchant) {
            res.status(201).send({ message: 'please provide merchant id' });
            return
        }
        const wallet = await Wallet.find({
            merchant: merchant._id,
        }).sort({ createdAt: -1 });

        if (!cardId) {
            console.log("created by cardToken");
          charged = await stripe.charges.create({
                amount: amount * 100,
                currency: 'usd',
                description: 'Wallet Recharged',
                source: cardToken
            });
        }

        if (!cardToken) {
            console.log("created by cardId");
             charged = await stripe.charges.create({
                // customer: "cus_N60HUukBBUp0cn",
                customer:merchant.stripe.customer.id,
                amount: amount * 100,
                currency: 'usd',
                description: 'Wallet Recharged',
                source: cardId
            });
        }
    
        if(!cardId && wallet.length === 1){
              // create the card if merchant Recharge the wallet in trail time
            const card = await stripe.customers.createSource(merchant.stripe.customer.id,
                {source: cardToken}
              );
            
           }

        if (wallet.length === 0) {
            const wallet = new Wallet({
                stripe: {
                    customer: {
                        id: merchant.stripe.customer.id
                    }
                },
                merchant: merchant._id,
                charged_amount: amount,
                amount: amount
            })
            await wallet.save();
          
           
        } else {
            if (wallet.length === 1 && wallet[0].amount === 0) {
                const initialWallet = await Wallet.findById(wallet[0]._id);
                initialWallet.charged_amount = amount;
                initialWallet.amount = amount;
                await initialWallet.save();
            } else {
                const lastBalance = wallet[0].amount;
                const lastWalletBalance = await Wallet.findById(wallet[0]._id);
                lastWalletBalance.amount = 0;
                lastWalletBalance.save();
                const totalAmount = parseInt(lastBalance) + parseInt(amount);
                const newwallet = new Wallet({
                    stripe: {
                        customer: {
                            id: merchant.stripe.customer.id
                        }
                    },
                    merchant: merchant._id,
                    amount: totalAmount,
                    charged_amount: amount
                })
                await newwallet.save();
            }
        }


        //  console.log("charge =>",charge);
         res.status(200).send(charged);  
    } catch (error) {
        res.status(400).send({
            message: error.message
        });
    }
}

const getCards = async (req, res) => {
    try {
        const token = req.get("X-JWT-Token");
        const decodedToken = decodeToken(token);
        if (!decodedToken) {
            res.status(201).send({ message: 'token not provided !' });
            return
        }

        const merchant = await Merchant.findById(decodedToken.data.merchantId);
        if (!merchant) {
            res.status(201).send({ message: 'please provide merchant id' });
            return
        }
        const cards = await stripe.customers.listSources(
            merchant.stripe.customer.id,
            { object: 'card', limit: 3 }
        );

        res.status(200).send(cards);
    } catch (error) {
        res.status(400).send({ message: error.message, subError: "Oops something went wrong in get cards" })
    }
}

module.exports = {
    getTransactionHistory,
    rechargeWallet,
    getCards
}