const jsonwebtoken = require('jsonwebtoken');

require('dotenv').config();

const signingKey = process.env.SIGNING_KEY;
const messageSigningKey = process.env.MESSAGE_SIGNING_KEY;

const verifyToken = (req, res, next) => {
    const token = req.get("X-JWT-Token");
    jsonwebtoken.verify(token, signingKey, (error, verifiedJwt) => {
        if (error) {
            return res.sendStatus(503);
        } else {
            return next();
        }
    });
};

const verifyTokenMessage = (req, res, next) => {
    const header = req.headers['authorization'];
    if (typeof header !== 'undefined') {
        const bearer = header.split(' ');
        const token = bearer[1];
        jsonwebtoken.verify(token, messageSigningKey, (error, verifiedJwt) => {
            return error ? res.sendStatus(503) : next();
        });
    }
};

module.exports = { verifyToken, verifyTokenMessage };